@@ -3,8 +3,7 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>", 
   fig.width=7, 
-  fig.height=5, 
-  fig.path="figs-class/"
+  fig.height=5 
 )
 
 
